@@ -19,47 +19,30 @@ RPC Controller
 import datetime
 import traceback
 
-from oslo_config import cfg
-from oslo_log import log as logging
-from oslo_utils import encodeutils
-import oslo_utils.importutils as imp
+from oslo.config import cfg
 import six
 from webob import exc
 
 from glance.common import client
 from glance.common import exception
-from glance.common import timeutils
 from glance.common import wsgi
-from glance.i18n import _, _LE
+import glance.openstack.common.importutils as imp
+import glance.openstack.common.log as logging
+from glance.openstack.common import timeutils
 
 LOG = logging.getLogger(__name__)
 
 
 rpc_opts = [
+    # NOTE(flaper87): Shamelessly copied
+    # from oslo rpc.
     cfg.ListOpt('allowed_rpc_exception_modules',
-                default=['glance.common.exception',
-                         'builtins',
+                default=['openstack.common.exception',
+                         'glance.common.exception',
                          'exceptions',
                          ],
-                help=_("""
-List of allowed exception modules to handle RPC exceptions.
-
-Provide a comma separated list of modules whose exceptions are
-permitted to be recreated upon receiving exception data via an RPC
-call made to Glance. The default list includes
-``glance.common.exception``, ``builtins``, and ``exceptions``.
-
-The RPC protocol permits interaction with Glance via calls across a
-network or within the same system. Including a list of exception
-namespaces with this option enables RPC to propagate the exceptions
-back to the users.
-
-Possible values:
-    * A comma separated list of valid exception modules
-
-Related options:
-    * None
-""")),
+                help='Modules of exceptions that are permitted to be recreated'
+                     'upon receiving exception data from an rpc call.'),
 ]
 
 CONF = cfg.CONF
@@ -68,23 +51,20 @@ CONF.register_opts(rpc_opts)
 
 class RPCJSONSerializer(wsgi.JSONResponseSerializer):
 
-    @staticmethod
-    def _to_primitive(_type, _value):
-        return {"_type": _type, "_value": _value}
-
     def _sanitizer(self, obj):
+        def to_primitive(_type, _value):
+            return {"_type": _type, "_value": _value}
+
         if isinstance(obj, datetime.datetime):
-            return self._to_primitive("datetime",
-                                      obj.isoformat())
+            return to_primitive("datetime", timeutils.strtime(obj))
 
         return super(RPCJSONSerializer, self)._sanitizer(obj)
 
 
 class RPCJSONDeserializer(wsgi.JSONRequestDeserializer):
 
-    @staticmethod
-    def _to_datetime(obj):
-        return timeutils.normalize_time(timeutils.parse_isotime(obj))
+    def _to_datetime(self, obj):
+        return timeutils.parse_strtime(obj)
 
     def _sanitizer(self, obj):
         try:
@@ -101,8 +81,6 @@ class Controller(object):
     This is the base controller for RPC based APIs. Commands
     handled by this controller respect the following form:
 
-    ::
-
         [{
             'command': 'method_name',
             'kwargs': {...}
@@ -111,9 +89,8 @@ class Controller(object):
     The controller is capable of processing more than one command
     per request and will always return a list of results.
 
-    :param bool raise_exc: Specifies whether to raise
-        exceptions instead of "serializing" them.
-
+    :params raise_exc: Boolean that specifies whether to raise
+    exceptions instead of "serializing" them.
     """
 
     def __init__(self, raise_exc=False):
@@ -124,17 +101,16 @@ class Controller(object):
         """
         Exports methods through the RPC Api.
 
-        :param resource: Resource's instance to register.
-        :param filtered: List of methods that *can* be registered. Read
-            as "Method must be in this list".
-        :param excluded: List of methods to exclude.
-        :param refiner: Callable to use as filter for methods.
-
-        :raises TypeError: If refiner is not callable.
+        :params resource: Resource's instance to register.
+        :params filtered: List of methods that *can* me registered. Read
+        as "Method must be in this list".
+        :params excluded: List of methods to exclude.
+        :params refiner: Callable to use as filter for methods.
 
+        :raises AssertionError: If refiner is not callable.
         """
 
-        funcs = [x for x in dir(resource) if not x.startswith("_")]
+        funcs = filter(lambda x: not x.startswith("_"), dir(resource))
 
         if filtered:
             funcs = [f for f in funcs if f in filtered]
@@ -143,6 +119,7 @@ class Controller(object):
             funcs = [f for f in funcs if f not in excluded]
 
         if refiner:
+            assert callable(refiner), "Refiner must be callable"
             funcs = filter(refiner, funcs)
 
         for name in funcs:
@@ -201,8 +178,8 @@ class Controller(object):
                 if self.raise_exc:
                     raise
 
-                cls, val = e.__class__, encodeutils.exception_to_unicode(e)
-                msg = (_LE("RPC Call Error: %(val)s\n%(tb)s") %
+                cls, val = e.__class__, six.text_type(e)
+                msg = (_("RPC Call Error: %(val)s\n%(tb)s") %
                        dict(val=val, tb=traceback.format_exc()))
                 LOG.error(msg)
 
@@ -211,8 +188,7 @@ class Controller(object):
                 module = cls.__module__
                 if module not in CONF.allowed_rpc_exception_modules:
                     cls = exception.RPCError
-                    val = encodeutils.exception_to_unicode(
-                        exception.RPCError(cls=cls, val=val))
+                    val = six.text_type(exception.RPCError(cls=cls, val=val))
 
                 cls_path = "%s.%s" % (cls.__module__, cls.__name__)
                 result = {"_error": {"cls": cls_path, "val": val}}
@@ -235,16 +211,13 @@ class RPCClient(client.BaseClient):
         """
         Execute multiple commands in a single request.
 
-        :param commands: List of commands to send. Commands
-            must respect the following form
-
-        ::
+        :params commands: List of commands to send. Commands
+        must respect the following form:
 
             {
                 'command': 'method_name',
                 'kwargs': method_kwargs
             }
-
         """
         body = self._serializer.to_json(commands)
         response = super(RPCClient, self).do_request('POST',
@@ -258,8 +231,8 @@ class RPCClient(client.BaseClient):
         the outgoing body and builds the command that will
         be sent.
 
-        :param method: The remote python method to call
-        :param kwargs: Dynamic parameters that will be
+        :params method: The remote python method to call
+        :params kwargs: Dynamic parameters that will be
             passed to the remote method.
         """
         content = self.bulk_request([{'command': method,
