@@ -15,40 +15,35 @@
 
 from contextlib import contextmanager
 import datetime
-import errno
 import hashlib
-import io
 import os
 import tempfile
 import time
-from unittest import mock
 
 import fixtures
-import glance_store as store
-from oslo_config import cfg
-from oslo_utils import fileutils
-from oslo_utils import units
+import six
+from six.moves import xrange
+import stubout
 
-from glance import async_
 from glance.common import exception
-from glance import context
-from glance import gateway as glance_gateway
 from glance import image_cache
-from glance.image_cache import prefetcher
-from glance.tests.unit import utils as unit_test_utils
+from glance.openstack.common import units
+#NOTE(bcwaldon): This is imported to load the registry config options
+import glance.registry  # noqa
+import glance.store.filesystem as fs_store
+import glance.store.s3 as s3_store
 from glance.tests import utils as test_utils
 from glance.tests.utils import skip_if_disabled
 from glance.tests.utils import xattr_writes_supported
 
 FIXTURE_LENGTH = 1024
-FIXTURE_DATA = b'*' * FIXTURE_LENGTH
-CONF = cfg.CONF
+FIXTURE_DATA = '*' * FIXTURE_LENGTH
 
 
 class ImageCacheTestCase(object):
 
     def _setup_fixture_file(self):
-        FIXTURE_FILE = io.BytesIO(FIXTURE_DATA)
+        FIXTURE_FILE = six.StringIO(FIXTURE_DATA)
 
         self.assertFalse(self.cache.is_cached(1))
 
@@ -71,7 +66,7 @@ class ImageCacheTestCase(object):
         """
         self._setup_fixture_file()
 
-        buff = io.BytesIO()
+        buff = six.StringIO()
         with self.cache.open_for_read(1) as cache_file:
             for chunk in cache_file:
                 buff.write(chunk)
@@ -85,7 +80,7 @@ class ImageCacheTestCase(object):
         """
         self._setup_fixture_file()
 
-        buff = io.BytesIO()
+        buff = six.StringIO()
         with self.cache.open_for_read(1) as cache_file:
             for chunk in cache_file:
                 buff.write(chunk)
@@ -119,7 +114,7 @@ class ImageCacheTestCase(object):
             self.assertFalse(self.cache.is_cached(image_id))
 
         for image_id in (1, 2):
-            FIXTURE_FILE = io.BytesIO(FIXTURE_DATA)
+            FIXTURE_FILE = six.StringIO(FIXTURE_DATA)
             self.assertTrue(self.cache.cache_image_file(image_id,
                                                         FIXTURE_FILE))
 
@@ -131,36 +126,11 @@ class ImageCacheTestCase(object):
         for image_id in (1, 2):
             self.assertFalse(self.cache.is_cached(image_id))
 
-    def _test_clean_invalid_path(self, failure=False):
-        invalid_file_path = os.path.join(self.cache_dir, 'invalid', '1')
-        invalid_file = open(invalid_file_path, 'wb')
-        invalid_file.write(FIXTURE_DATA)
-        invalid_file.close()
-
-        self.assertTrue(os.path.exists(invalid_file_path))
-
-        if failure:
-            with mock.patch.object(
-                    fileutils, 'delete_if_exists') as mock_delete:
-                mock_delete.side_effect = OSError(errno.ENOENT, '')
-                try:
-                    self.cache.clean()
-                except OSError:
-                    self.assertTrue(os.path.exists(invalid_file_path))
-        else:
-            self.cache.clean()
-            self.assertFalse(os.path.exists(invalid_file_path))
-
-    @skip_if_disabled
-    def test_clean_invalid_path(self):
-        """Test the clean method removes expected image from invalid path."""
-        self._test_clean_invalid_path()
-
     @skip_if_disabled
     def test_clean_stalled(self):
         """Test the clean method removes expected images."""
         incomplete_file_path = os.path.join(self.cache_dir, 'incomplete', '1')
-        incomplete_file = open(incomplete_file_path, 'wb')
+        incomplete_file = open(incomplete_file_path, 'w')
         incomplete_file.write(FIXTURE_DATA)
         incomplete_file.close()
 
@@ -170,8 +140,8 @@ class ImageCacheTestCase(object):
 
         self.assertFalse(os.path.exists(incomplete_file_path))
 
-    def _test_clean_stall_time(self, stall_time=None, days=2,
-                               stall_failed=False):
+    @skip_if_disabled
+    def test_clean_stalled_nonzero_stall_time(self):
         """
         Test the clean method removes the stalled images as expected
         """
@@ -180,13 +150,13 @@ class ImageCacheTestCase(object):
         incomplete_file_path_2 = os.path.join(self.cache_dir,
                                               'incomplete', '2')
         for f in (incomplete_file_path_1, incomplete_file_path_2):
-            incomplete_file = open(f, 'wb')
+            incomplete_file = open(f, 'w')
             incomplete_file.write(FIXTURE_DATA)
             incomplete_file.close()
 
         mtime = os.path.getmtime(incomplete_file_path_1)
-        pastday = (datetime.datetime.fromtimestamp(mtime) -
-                   datetime.timedelta(days=days))
+        pastday = datetime.datetime.fromtimestamp(mtime) - \
+            datetime.timedelta(days=1)
         atime = int(time.mktime(pastday.timetuple()))
         mtime = atime
         os.utime(incomplete_file_path_1, (atime, mtime))
@@ -194,29 +164,11 @@ class ImageCacheTestCase(object):
         self.assertTrue(os.path.exists(incomplete_file_path_1))
         self.assertTrue(os.path.exists(incomplete_file_path_2))
 
-        # If stall_time is None then it will wait for default time
-        # of `image_cache_stall_time` which is 24 hours
-        if stall_failed:
-            with mock.patch.object(
-                    fileutils, 'delete_if_exists') as mock_delete:
-                mock_delete.side_effect = OSError(errno.ENOENT, '')
-                self.cache.clean(stall_time=stall_time)
-                self.assertTrue(os.path.exists(incomplete_file_path_1))
-        else:
-            self.cache.clean(stall_time=stall_time)
-            self.assertFalse(os.path.exists(incomplete_file_path_1))
+        self.cache.clean(stall_time=3600)
 
+        self.assertFalse(os.path.exists(incomplete_file_path_1))
         self.assertTrue(os.path.exists(incomplete_file_path_2))
 
-    @skip_if_disabled
-    def test_clean_stalled_none_stall_time(self):
-        self._test_clean_stall_time()
-
-    @skip_if_disabled
-    def test_clean_stalled_nonzero_stall_time(self):
-        """Test the clean method removes expected images."""
-        self._test_clean_stall_time(stall_time=3600, days=1)
-
     @skip_if_disabled
     def test_prune(self):
         """
@@ -224,47 +176,38 @@ class ImageCacheTestCase(object):
         """
         self.assertEqual(0, self.cache.get_cache_size())
 
-        # Add a bunch of images to the cache. The max cache size for the cache
-        # is set to 5KB and each image is 1K. We use 11 images in this test.
-        # The first 10 are added to and retrieved from cache in the same order.
-        # Then, the 11th image is added to cache but not retrieved before we
-        # prune. We should see only 5 images left after pruning, and the
-        # images that are least recently accessed should be the ones pruned...
-        for x in range(10):
-            FIXTURE_FILE = io.BytesIO(FIXTURE_DATA)
-            self.assertTrue(self.cache.cache_image_file(x, FIXTURE_FILE))
+        # Add a bunch of images to the cache. The max cache
+        # size for the cache is set to 5KB and each image is
+        # 1K. We add 10 images to the cache and then we'll
+        # prune it. We should see only 5 images left after
+        # pruning, and the images that are least recently accessed
+        # should be the ones pruned...
+        for x in xrange(10):
+            FIXTURE_FILE = six.StringIO(FIXTURE_DATA)
+            self.assertTrue(self.cache.cache_image_file(x,
+                                                        FIXTURE_FILE))
 
         self.assertEqual(10 * units.Ki, self.cache.get_cache_size())
 
         # OK, hit the images that are now cached...
-        for x in range(10):
-            buff = io.BytesIO()
+        for x in xrange(10):
+            buff = six.StringIO()
             with self.cache.open_for_read(x) as cache_file:
                 for chunk in cache_file:
                     buff.write(chunk)
 
-        # Add a new image to cache.
-        # This is specifically to test the bug: 1438564
-        FIXTURE_FILE = io.BytesIO(FIXTURE_DATA)
-        self.assertTrue(self.cache.cache_image_file(99, FIXTURE_FILE))
-
         self.cache.prune()
 
         self.assertEqual(5 * units.Ki, self.cache.get_cache_size())
 
-        # Ensure images 0, 1, 2, 3, 4 & 5 are not cached anymore
-        for x in range(0, 6):
+        for x in xrange(0, 5):
             self.assertFalse(self.cache.is_cached(x),
                              "Image %s was cached!" % x)
 
-        # Ensure images 6, 7, 8 and 9 are still cached
-        for x in range(6, 10):
+        for x in xrange(5, 10):
             self.assertTrue(self.cache.is_cached(x),
                             "Image %s was not cached!" % x)
 
-        # Ensure the newly added image, 99, is still cached
-        self.assertTrue(self.cache.is_cached(99), "Image 99 was not cached!")
-
     @skip_if_disabled
     def test_prune_to_zero(self):
         """Test that an image_cache_max_size of 0 doesn't kill the pruner
@@ -273,13 +216,13 @@ class ImageCacheTestCase(object):
         """
         self.assertEqual(0, self.cache.get_cache_size())
 
-        FIXTURE_FILE = io.BytesIO(FIXTURE_DATA)
+        FIXTURE_FILE = six.StringIO(FIXTURE_DATA)
         self.assertTrue(self.cache.cache_image_file('xxx', FIXTURE_FILE))
 
         self.assertEqual(1024, self.cache.get_cache_size())
 
         # OK, hit the image that is now cached...
-        buff = io.BytesIO()
+        buff = six.StringIO()
         with self.cache.open_for_read('xxx') as cache_file:
             for chunk in cache_file:
                 buff.write(chunk)
@@ -299,7 +242,7 @@ class ImageCacheTestCase(object):
         self.assertFalse(self.cache.is_cached(1))
         self.assertFalse(self.cache.is_queued(1))
 
-        FIXTURE_FILE = io.BytesIO(FIXTURE_DATA)
+        FIXTURE_FILE = six.StringIO(FIXTURE_DATA)
 
         self.assertTrue(self.cache.queue_image(1))
 
@@ -324,26 +267,12 @@ class ImageCacheTestCase(object):
 
         self.cache.delete_cached_image(1)
 
-        # Test that we return false if image is being cached
-        incomplete_file_path = os.path.join(self.cache_dir, 'incomplete', '1')
-        incomplete_file = open(incomplete_file_path, 'wb')
-        incomplete_file.write(FIXTURE_DATA)
-        incomplete_file.close()
-
-        self.assertFalse(self.cache.is_queued(1))
-        self.assertFalse(self.cache.is_cached(1))
-        self.assertTrue(self.cache.driver.is_being_cached(1))
-
-        self.assertFalse(self.cache.queue_image(1))
-        self.cache.clean(stall_time=0)
-
-        for x in range(3):
+        for x in xrange(3):
             self.assertTrue(self.cache.queue_image(x))
 
-        self.assertEqual(['0', '1', '2'],
-                         self.cache.get_queued_images())
+        self.assertEqual(self.cache.get_queued_images(),
+                         ['0', '1', '2'])
 
-    @skip_if_disabled
     def test_open_for_write_good(self):
         """
         Test to see if open_for_write works in normal case
@@ -353,7 +282,7 @@ class ImageCacheTestCase(object):
         image_id = '1'
         self.assertFalse(self.cache.is_cached(image_id))
         with self.cache.driver.open_for_write(image_id) as cache_file:
-            cache_file.write(b'a')
+            cache_file.write('a')
         self.assertTrue(self.cache.is_cached(image_id),
                         "Image %s was NOT cached!" % image_id)
         # make sure it has tidied up
@@ -363,13 +292,12 @@ class ImageCacheTestCase(object):
         self.assertFalse(os.path.exists(incomplete_file_path))
         self.assertFalse(os.path.exists(invalid_file_path))
 
-    @skip_if_disabled
     def test_open_for_write_with_exception(self):
         """
         Test to see if open_for_write works in a failure case for each driver
         This case is where an exception is raised while the file is being
-        written. The image is partially filled in cache and filling won't
-        resume so verify the image is moved to invalid/ directory
+        written. The image is partially filled in cache and filling wont resume
+        so verify the image is moved to invalid/ directory
         """
         # test a case where an exception is raised while the file is open
         image_id = '1'
@@ -388,7 +316,6 @@ class ImageCacheTestCase(object):
         self.assertFalse(os.path.exists(incomplete_file_path))
         self.assertTrue(os.path.exists(invalid_file_path))
 
-    @skip_if_disabled
     def test_caching_iterator(self):
         """
         Test to see if the caching iterator interacts properly with the driver
@@ -398,11 +325,11 @@ class ImageCacheTestCase(object):
         # test a case where an exception NOT raised while the file is open,
         # and a consuming iterator completes
         def consume(image_id):
-            data = [b'a', b'b', b'c', b'd', b'e', b'f']
+            data = ['a', 'b', 'c', 'd', 'e', 'f']
             checksum = None
             caching_iter = self.cache.get_caching_iter(image_id, checksum,
                                                        iter(data))
-            self.assertEqual(data, list(caching_iter))
+            self.assertEqual(list(caching_iter), data)
 
         image_id = '1'
         self.assertFalse(self.cache.is_cached(image_id))
@@ -416,16 +343,15 @@ class ImageCacheTestCase(object):
         self.assertFalse(os.path.exists(incomplete_file_path))
         self.assertFalse(os.path.exists(invalid_file_path))
 
-    @skip_if_disabled
     def test_caching_iterator_handles_backend_failure(self):
         """
         Test that when the backend fails, caching_iter does not continue trying
         to consume data, and rolls back the cache.
         """
         def faulty_backend():
-            data = [b'a', b'b', b'c', b'Fail', b'd', b'e', b'f']
+            data = ['a', 'b', 'c', 'Fail', 'd', 'e', 'f']
             for d in data:
-                if d == b'Fail':
+                if d == 'Fail':
                     raise exception.GlanceException('Backend failure')
                 yield d
 
@@ -440,22 +366,21 @@ class ImageCacheTestCase(object):
         # make sure bad image was not cached
         self.assertFalse(self.cache.is_cached(image_id))
 
-    @skip_if_disabled
     def test_caching_iterator_falloffend(self):
         """
         Test to see if the caching iterator interacts properly with the driver
         in a case where the iterator is only partially consumed. In this case
-        the image is only partially filled in cache and filling won't resume.
+        the image is only partially filled in cache and filling wont resume.
         When the iterator goes out of scope the driver should have closed the
         image and moved it from incomplete/ to invalid/
         """
         # test a case where a consuming iterator just stops.
         def falloffend(image_id):
-            data = [b'a', b'b', b'c', b'd', b'e', b'f']
+            data = ['a', 'b', 'c', 'd', 'e', 'f']
             checksum = None
             caching_iter = self.cache.get_caching_iter(image_id, checksum,
                                                        iter(data))
-            self.assertEqual(b'a', next(caching_iter))
+            self.assertEqual(caching_iter.next(), 'a')
 
         image_id = '1'
         self.assertFalse(self.cache.is_cached(image_id))
@@ -469,38 +394,66 @@ class ImageCacheTestCase(object):
         self.assertFalse(os.path.exists(incomplete_file_path))
         self.assertTrue(os.path.exists(invalid_file_path))
 
-    @skip_if_disabled
     def test_gate_caching_iter_good_checksum(self):
-        image = b"12345678990abcdefghijklmnop"
+        image = "12345678990abcdefghijklmnop"
         image_id = 123
 
-        md5 = hashlib.md5(usedforsecurity=False)
+        md5 = hashlib.md5()
         md5.update(image)
         checksum = md5.hexdigest()
 
-        with mock.patch('glance.db.get_api') as mock_get_db:
-            db = unit_test_utils.FakeDB(initialize=False)
-            mock_get_db.return_value = db
-            cache = image_cache.ImageCache()
-
-        img_iter = cache.get_caching_iter(image_id, checksum, [image])
+        cache = image_cache.ImageCache()
+        img_iter = cache.get_caching_iter(image_id, checksum, image)
         for chunk in img_iter:
             pass
         # checksum is valid, fake image should be cached:
         self.assertTrue(cache.is_cached(image_id))
 
-    @skip_if_disabled
+    def test_gate_caching_iter_fs_chunked_file(self):
+        """Tests get_caching_iter when using a filesystem ChunkedFile"""
+        image_id = 123
+
+        with tempfile.NamedTemporaryFile() as test_data_file:
+            test_data_file.write(FIXTURE_DATA)
+            test_data_file.seek(0)
+            image = fs_store.ChunkedFile(test_data_file.name)
+            md5 = hashlib.md5()
+            md5.update(FIXTURE_DATA)
+            checksum = md5.hexdigest()
+
+            cache = image_cache.ImageCache()
+            img_iter = cache.get_caching_iter(image_id, checksum, image)
+            for chunk in img_iter:
+                pass
+            # checksum is valid, fake image should be cached:
+            self.assertTrue(cache.is_cached(image_id))
+
+    def test_gate_caching_iter_s3_chunked_file(self):
+        """Tests get_caching_iter when using an S3 ChunkedFile"""
+        image_id = 123
+
+        with tempfile.NamedTemporaryFile() as test_data_file:
+            test_data_file.write(FIXTURE_DATA)
+            test_data_file.seek(0)
+            image = s3_store.ChunkedFile(test_data_file)
+            md5 = hashlib.md5()
+            md5.update(FIXTURE_DATA)
+            checksum = md5.hexdigest()
+
+            cache = image_cache.ImageCache()
+            img_iter = cache.get_caching_iter(image_id, checksum, image)
+            for chunk in img_iter:
+                pass
+            # checksum is valid, fake image should be cached:
+            self.assertTrue(cache.is_cached(image_id))
+
     def test_gate_caching_iter_bad_checksum(self):
-        image = b"12345678990abcdefghijklmnop"
+        image = "12345678990abcdefghijklmnop"
         image_id = 123
         checksum = "foobar"  # bad.
 
-        with mock.patch('glance.db.get_api') as mock_get_db:
-            db = unit_test_utils.FakeDB(initialize=False)
-            mock_get_db.return_value = db
-            cache = image_cache.ImageCache()
-
-        img_iter = cache.get_caching_iter(image_id, checksum, [image])
+        cache = image_cache.ImageCache()
+        img_iter = cache.get_caching_iter(image_id, checksum, image)
 
         def reader():
             for chunk in img_iter:
@@ -551,136 +504,38 @@ class TestImageCacheXattr(test_utils.BaseTestCase,
             return
 
 
-class TestImageCacheCentralizedDb(test_utils.BaseTestCase,
-                                  ImageCacheTestCase):
-
-    """Tests image caching when Centralized DB is used in cache"""
-
-    def setUp(self):
-        super(TestImageCacheCentralizedDb, self).setUp()
-
-        self.inited = True
-        self.disabled = False
-        self.cache_dir = self.useFixture(fixtures.TempDir()).path
-        self.config(image_cache_dir=self.cache_dir,
-                    image_cache_driver='centralized_db',
-                    image_cache_max_size=5 * units.Ki,
-                    worker_self_reference_url='http://workerx')
-
-        with mock.patch('glance.db.get_api') as mock_get_db:
-            self.db = unit_test_utils.FakeDB(initialize=False)
-            mock_get_db.return_value = self.db
-            self.cache = image_cache.ImageCache()
-
-    def test_node_reference_create_duplicate(self):
-        with mock.patch('glance.db.get_api') as mock_get_db:
-            self.db = unit_test_utils.FakeDB(initialize=False)
-            mock_get_db.return_value = self.db
-            with mock.patch.object(
-                    self.db, 'node_reference_create') as mock_node_create:
-                mock_node_create.side_effect = exception.Duplicate
-                with mock.patch.object(
-                        image_cache.drivers.centralized_db, 'LOG') as mock_log:
-                    image_cache.ImageCache()
-                    expected_calls = [
-                        mock.call('Node reference is already recorded, '
-                                  'ignoring it')
-                    ]
-                    mock_log.debug.assert_has_calls(expected_calls)
-
-    def test_get_least_recently_accessed_os_error(self):
-        self.assertEqual(0, self.cache.get_cache_size())
-        for x in range(10):
-            FIXTURE_FILE = io.BytesIO(FIXTURE_DATA)
-            self.assertTrue(self.cache.cache_image_file(x, FIXTURE_FILE))
-
-        self.assertEqual(10 * units.Ki, self.cache.get_cache_size())
-
-        with mock.patch.object(os, 'stat') as mock_stat:
-            mock_stat.side_effect = OSError
-            image_id, size = self.cache.driver.get_least_recently_accessed()
-            self.assertEqual(0, size)
-
-    @skip_if_disabled
-    def test_clean_stalled_fails(self):
-        """Test the clean method fails to delete file, ignores the failure"""
-        self._test_clean_stall_time(stall_time=3600, days=1,
-                                    stall_failed=True)
-
-    @skip_if_disabled
-    def test_clean_invalid_path_fails(self):
-        """Test the clean method fails to remove image from invalid path."""
-        self._test_clean_invalid_path(failure=True)
-
-
 class TestImageCacheSqlite(test_utils.BaseTestCase,
                            ImageCacheTestCase):
 
     """Tests image caching when SQLite is used in cache"""
 
     def setUp(self):
+        """
+        Test to see if the pre-requisites for the image cache
+        are working (python-sqlite3 installed)
+        """
         super(TestImageCacheSqlite, self).setUp()
 
+        if getattr(self, 'disable', False):
+            return
+
+        if not getattr(self, 'inited', False):
+            try:
+                import sqlite3  # noqa
+            except ImportError:
+                self.inited = True
+                self.disabled = True
+                self.disabled_message = ("python-sqlite3 not installed.")
+                return
+
+        self.inited = True
+        self.disabled = False
         self.cache_dir = self.useFixture(fixtures.TempDir()).path
         self.config(image_cache_dir=self.cache_dir,
                     image_cache_driver='sqlite',
                     image_cache_max_size=5 * units.Ki)
         self.cache = image_cache.ImageCache()
 
-    @mock.patch('glance.db.get_api')
-    def _test_prefetcher(self, mock_get_db):
-        self.config(enabled_backends={'cheap': 'file'})
-        store.register_store_opts(CONF)
-        self.config(filesystem_store_datadir='/tmp', group='cheap')
-        store.create_multi_stores(CONF)
-
-        tempf = tempfile.NamedTemporaryFile()
-        tempf.write(b'foo')
-
-        db = unit_test_utils.FakeDB(initialize=False)
-        mock_get_db.return_value = db
-
-        ctx = context.RequestContext(is_admin=True, roles=['admin'])
-        gateway = glance_gateway.Gateway()
-        image_factory = gateway.get_image_factory(ctx)
-        image_repo = gateway.get_repo(ctx)
-        fetcher = prefetcher.Prefetcher()
-
-        # Create an image with no values set and queue it
-        image = image_factory.new_image()
-        image_repo.add(image)
-        fetcher.cache.queue_image(image.image_id)
-
-        # Image is not active, so it should fail to cache, but remain queued
-        self.assertFalse(fetcher.run())
-        self.assertFalse(fetcher.cache.is_cached(image.image_id))
-        self.assertTrue(fetcher.cache.is_queued(image.image_id))
-
-        # Set the disk/container format and give it a location
-        image.disk_format = 'raw'
-        image.container_format = 'bare'
-        image.status = 'active'
-        loc = {'url': 'file://%s' % tempf.name, 'metadata': {'store': 'cheap'}}
-        with mock.patch('glance.location._check_image_location'):
-            # FIXME(danms): Why do I have to do this?
-            image.locations = [loc]
-        image_repo.save(image)
-
-        # Image is now active and has a location, so it should cache
-        self.assertTrue(fetcher.run())
-        self.assertTrue(fetcher.cache.is_cached(image.image_id))
-        self.assertFalse(fetcher.cache.is_queued(image.image_id))
-
-    @mock.patch('glance.async_._THREADPOOL_MODEL', new=None)
-    def test_prefetcher_greenthread(self):
-        async_.set_threadpool_model('eventlet')
-        self._test_prefetcher()
-
-    @mock.patch('glance.async_._THREADPOOL_MODEL', new=None)
-    def test_prefetcher_native(self):
-        async_.set_threadpool_model('native')
-        self._test_prefetcher()
-
 
 class TestImageCacheNoDep(test_utils.BaseTestCase):
 
@@ -692,7 +547,9 @@ class TestImageCacheNoDep(test_utils.BaseTestCase):
         def init_driver(self2):
             self2.driver = self.driver
 
-        self.mock_object(image_cache.ImageCache, 'init_driver', init_driver)
+        self.stubs = stubout.StubOutForTesting()
+        self.stubs.Set(image_cache.ImageCache, 'init_driver', init_driver)
+        self.addCleanup(self.stubs.UnsetAll)
 
     def test_get_caching_iter_when_write_fails(self):
 
@@ -713,10 +570,10 @@ class TestImageCacheNoDep(test_utils.BaseTestCase):
 
         self.driver = FailingFileDriver()
         cache = image_cache.ImageCache()
-        data = [b'a', b'b', b'c', b'Fail', b'd', b'e', b'f']
+        data = ['a', 'b', 'c', 'Fail', 'd', 'e', 'f']
 
         caching_iter = cache.get_caching_iter('dummy_id', None, iter(data))
-        self.assertEqual(data, list(caching_iter))
+        self.assertEqual(list(caching_iter), data)
 
     def test_get_caching_iter_when_open_fails(self):
 
@@ -731,23 +588,7 @@ class TestImageCacheNoDep(test_utils.BaseTestCase):
 
         self.driver = OpenFailingDriver()
         cache = image_cache.ImageCache()
-        data = [b'a', b'b', b'c', b'd', b'e', b'f']
+        data = ['a', 'b', 'c', 'd', 'e', 'f']
 
         caching_iter = cache.get_caching_iter('dummy_id', None, iter(data))
-        self.assertEqual(data, list(caching_iter))
-
-
-class TestImagePrefetcher(test_utils.BaseTestCase):
-    def setUp(self):
-        super(TestImagePrefetcher, self).setUp()
-        self.cache_dir = self.useFixture(fixtures.TempDir()).path
-        self.config(image_cache_dir=self.cache_dir,
-                    image_cache_driver='xattr',
-                    image_cache_max_size=5 * units.Ki)
-        self.prefetcher = prefetcher.Prefetcher()
-
-    def test_fetch_image_into_cache_without_auth(self):
-        with mock.patch.object(self.prefetcher.gateway,
-                               'get_repo') as mock_get:
-            self.prefetcher.fetch_image_into_cache('fake-image-id')
-            mock_get.assert_called_once_with(mock.ANY)
+        self.assertEqual(list(caching_iter), data)
