@@ -13,23 +13,21 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-
-from cryptography import exceptions as crypto_exception
-import glance_store as store
-from unittest import mock
 import urllib
+import urlparse
 
-from oslo_config import cfg
+from oslo.config import cfg
 
-from glance.async_.flows._internal_plugins import base_download
 from glance.common import exception
-from glance.common import store_utils
 from glance.common import wsgi
 import glance.context
 import glance.db.simple.api as simple_db
+import glance.openstack.common.log as logging
+import glance.store
 
 
 CONF = cfg.CONF
+LOG = logging.getLogger(__name__)
 
 UUID1 = 'c80a1a6c-bd1f-41c5-90ee-81afedb1d58d'
 UUID2 = '971ec09a-8067-4bc8-a91f-ae3557f1c4c7'
@@ -45,36 +43,29 @@ BASE_URI = 'http://storeurl.com/container'
 
 
 def sort_url_by_qs_keys(url):
-    # NOTE(kragniz): this only sorts the keys of the query string of a url.
+    #NOTE(kragniz): this only sorts the keys of the query string of a url.
     # For example, an input of '/v2/tasks?sort_key=id&sort_dir=asc&limit=10'
     # returns '/v2/tasks?limit=10&sort_dir=asc&sort_key=id'. This is to prevent
     # non-deterministic ordering of the query string causing problems with unit
     # tests.
 
-    parsed = urllib.parse.urlparse(url)
-    queries = urllib.parse.parse_qsl(parsed.query, True)
+    parsed = urlparse.urlparse(url)
+    queries = urlparse.parse_qsl(parsed.query, True)
     sorted_query = sorted(queries, key=lambda x: x[0])
 
-    encoded_sorted_query = urllib.parse.urlencode(sorted_query, True)
+    encoded_sorted_query = urllib.urlencode(sorted_query, True)
 
     url_parts = (parsed.scheme, parsed.netloc, parsed.path,
                  parsed.params, encoded_sorted_query,
                  parsed.fragment)
 
-    return urllib.parse.urlunparse(url_parts)
+    return urlparse.urlunparse(url_parts)
 
 
 def get_fake_request(path='', method='POST', is_admin=False, user=USER1,
-                     roles=None, headers=None, tenant=TENANT1):
-    if roles is None:
-        roles = ['member', 'reader']
-
+                     roles=['member'], tenant=TENANT1):
     req = wsgi.Request.blank(path)
     req.method = method
-    req.headers = {'x-openstack-request-id': 'my-req'}
-
-    if headers is not None:
-        req.headers.update(headers)
 
     kwargs = {
         'user': user,
@@ -87,53 +78,23 @@ def get_fake_request(path='', method='POST', is_admin=False, user=USER1,
     return req
 
 
-def fake_get_size_from_backend(uri, context=None):
+def fake_get_size_from_backend(context, uri):
     return 1
 
 
-def fake_get_verifier(context, img_signature_certificate_uuid,
-                      img_signature_hash_method, img_signature,
-                      img_signature_key_type):
-    verifier = mock.Mock()
-    if (img_signature is not None and img_signature == 'VALID'):
-        verifier.verify.return_value = None
-    else:
-        ex = crypto_exception.InvalidSignature()
-        verifier.verify.side_effect = ex
-    return verifier
-
-
-def get_fake_context(user=USER1, tenant=TENANT1, roles=None, is_admin=False):
-    if roles is None:
-        roles = ['member']
-
-    kwargs = {
-        'user': user,
-        'tenant': tenant,
-        'roles': roles,
-        'is_admin': is_admin,
-    }
-
-    context = glance.context.RequestContext(**kwargs)
-    return context
-
-
 class FakeDB(object):
 
-    def __init__(self, initialize=True):
+    def __init__(self):
         self.reset()
-        if initialize:
-            self.init_db()
+        self.init_db()
 
     @staticmethod
     def init_db():
         images = [
             {'id': UUID1, 'owner': TENANT1, 'status': 'queued',
              'locations': [{'url': '%s/%s' % (BASE_URI, UUID1),
-                            'metadata': {}, 'status': 'queued'}],
-             'disk_format': 'raw', 'container_format': 'bare'},
-            {'id': UUID2, 'owner': TENANT1, 'status': 'queued',
-             'disk_format': 'raw', 'container_format': 'bare'},
+                            'metadata': {}}]},
+            {'id': UUID2, 'owner': TENANT1, 'status': 'queued'},
         ]
         [simple_db.image_create(None, image) for image in images]
 
@@ -153,34 +114,6 @@ class FakeDB(object):
         return getattr(simple_db, key)
 
 
-class FakeStoreUtils(object):
-    def __init__(self, store_api):
-        self.store_api = store_api
-
-    def safe_delete_from_backend(self, context, id, location):
-        try:
-            del self.store_api.data[location['url']]
-        except KeyError:
-            pass
-
-    def schedule_delayed_delete_from_backend(self, context, id, location):
-        pass
-
-    def delete_image_location_from_backend(self, context,
-                                           image_id, location):
-        if CONF.delayed_delete:
-            self.schedule_delayed_delete_from_backend(context, image_id,
-                                                      location)
-        else:
-            self.safe_delete_from_backend(context, image_id, location)
-
-    def validate_external_location(self, uri):
-        if uri and urllib.parse.urlparse(uri).scheme:
-            return store_utils.validate_external_location(uri)
-        else:
-            return True
-
-
 class FakeStoreAPI(object):
     def __init__(self, store_metadata=None):
         self.data = {
@@ -196,34 +129,42 @@ class FakeStoreAPI(object):
     def create_stores(self):
         pass
 
-    def set_acls(self, uri, public=False, read_tenants=None,
-                 write_tenants=None, context=None):
-        if read_tenants is None:
-            read_tenants = []
-        if write_tenants is None:
-            write_tenants = []
-
+    def set_acls(self, context, uri, public=False,
+                 read_tenants=[], write_tenants=[]):
         self.acls[uri] = {
             'public': public,
             'read': read_tenants,
             'write': write_tenants,
         }
 
-    def get_from_backend(self, location, offset=0,
-                         chunk_size=None, context=None):
+    def get_from_backend(self, context, location):
         try:
             scheme = location[:location.find('/') - 1]
             if scheme == 'unknown':
-                raise store.UnknownScheme(scheme=scheme)
+                raise exception.UnknownScheme(scheme=scheme)
             return self.data[location]
         except KeyError:
-            raise store.NotFound(image=location)
+            raise exception.NotFound()
 
-    def get_size_from_backend(self, location, context=None):
-        return self.get_from_backend(location, context=context)[1]
+    def safe_delete_from_backend(self, context, uri, id, **kwargs):
+        try:
+            del self.data[uri]
+        except KeyError:
+            pass
 
-    def add_to_backend(self, conf, image_id, data, size,
-                       scheme=None, context=None, verifier=None):
+    def schedule_delayed_delete_from_backend(self, context, uri, id, **kwargs):
+        pass
+
+    def delete_image_from_backend(self, context, store_api, image_id, uri):
+        if CONF.delayed_delete:
+            self.schedule_delayed_delete_from_backend(context, uri, image_id)
+        else:
+            self.safe_delete_from_backend(context, uri, image_id)
+
+    def get_size_from_backend(self, context, location):
+        return self.get_from_backend(context, location)[1]
+
+    def add_to_backend(self, context, scheme, image_id, data, size):
         store_max_size = 7
         current_store_size = 2
         for location in self.data.keys():
@@ -236,57 +177,16 @@ class FakeStoreAPI(object):
             size = len(data.data.fd)
         if (current_store_size + size) > store_max_size:
             raise exception.StorageFull()
-        if context.user_id == USER2:
+        if context.user == USER2:
             raise exception.Forbidden()
-        if context.user_id == USER3:
+        if context.user == USER3:
             raise exception.StorageWriteDenied()
         self.data[image_id] = (data, size)
         checksum = 'Z'
         return (image_id, size, checksum, self.store_metadata)
 
-    def add_to_backend_with_multihash(
-            self, conf, image_id, data, size, hashing_algo,
-            scheme=None, context=None, verifier=None):
-        store_max_size = 7
-        current_store_size = 2
-        for location in self.data.keys():
-            if image_id in location:
-                raise exception.Duplicate()
-        if not size:
-            # 'data' is a string wrapped in a LimitingReader|CooperativeReader
-            # pipeline, so peek under the hood of those objects to get at the
-            # string itself.
-            size = len(data.data.fd)
-        if (current_store_size + size) > store_max_size:
-            raise exception.StorageFull()
-        if context.user_id == USER2:
-            raise exception.Forbidden()
-        if context.user_id == USER3:
-            raise exception.StorageWriteDenied()
-        self.data[image_id] = (data, size)
-        checksum = 'Z'
-        multihash = 'ZZ'
-        return (image_id, size, checksum, multihash, self.store_metadata)
-
     def check_location_metadata(self, val, key=''):
-        store.check_location_metadata(val)
-
-    def delete_from_backend(self, uri, context=None):
-        pass
-
-
-class FakeStoreAPIReader(FakeStoreAPI):
-    """A store API that actually reads from the data pipe."""
-
-    def add_to_backend_with_multihash(self, conf, image_id, data, size,
-                                      hashing_algo, scheme=None, context=None,
-                                      verifier=None):
-        for chunk in data:
-            pass
-
-        return super(FakeStoreAPIReader, self).add_to_backend_with_multihash(
-            conf, image_id, data, size, hashing_algo,
-            scheme=scheme, context=context, verifier=verifier)
+        glance.store.check_location_metadata(val)
 
 
 class FakePolicyEnforcer(object):
@@ -307,11 +207,10 @@ class FakeNotifier(object):
         self.log = []
 
     def _notify(self, event_type, payload, level):
-        log = {
-            'notification_type': level,
-            'event_type': event_type,
-            'payload': payload
-        }
+        log = {}
+        log['notification_type'] = level
+        log['event_type'] = event_type
+        log['payload'] = payload
         self.log.append(log)
 
     def warn(self, event_type, payload):
@@ -374,8 +273,3 @@ class FakeTask(object):
     def fail(self, message):
         self.message = message
         self._status = 'failure'
-
-
-class FakeBaseDownloadPlugin(base_download.BaseDownload):
-    def execute(self):
-        pass
